# This file gives some general parameter definitions
# for the IMIG model published in Broquet, Yearsley et al (2009) Molecular Ecology

  # Files containing the input data (sample1 = pre-dispersal, sample2=post-dispersal)
  sample1Filename = 'sample1_Genotypes.txt'
  sample2Filename = 'sample2_Genotypes.txt'

  # demeGroups      = A vector specifying which group each population should be placed in. 
  #                   A group called 0 will be removed from the analysis
  #                   e.g. c(1,2,2,3,0) 5 populations with populations 2 and 3 grouped together
  #                   and opulation 5 not included in the analysis
 demeGroups <- c(1,2,2,3,3) # 5 populations, pops 2 and 3 grouped, pops 4 and 5 grouped
  
  # Define prior distribution (mean and coeff of var)
  # for prob of migration (1-m = prob of philopatry)
  mPrior_Mean <- 0.66666
  mPrior_CV <- 1.0

  # Number of chains that openBugs should run
  nChain <- 2

  # If TRUE then runs the model with BRugs
  runBRugs = FALSE
  
  #########################################################
  ## Additional parameters for use with the BRugs package
  #
  
  # Prefix for final results file 
  outputPrefix <- "example"

  # List of parameters to save
  paramSave <- list( "m", "phi", "mu.phi", "Sigma.phi" )
  # Length of the burnin period (4000 is usually a minimum for our models)
  burninIters <- 10000
  # Length of chain used to record the data (after a burnin period)
  datarecordIters <- 2000
  # Thin parameter (the number of iterations between each recorded value)
  thinParam <- 100
  # The total number of iteraction is burnIters + datarecordIters*thinParam    
    
  # If TRUE then the initial data are over dispersed. This is done by running 
  # a first-pass model and then selecting initial data from the tails of the
  # posterior distributions of the first-pass model
  overdisperseInits <- TRUE

    